<template>
  <div class="notice">
    <el-dialog
        v-model="dialogVisible"
        title="创建签署项目"
        width="50%"
        :before-close="handleClose"
        :close-on-press-escape="false"
        :close-on-click-modal="false"
    >
      <el-form :model="state.form" size="default" ref="busRef" :rules="state.formRules" label-width="150px" >
        <el-form-item label="项目名称:" prop="name" >
          <el-input v-model="state.form.name" placeholder="请输入项目名称"></el-input>
        </el-form-item>
        <el-form-item label="最初签署人:" prop="deptId" >
          <div style="display: flex;">
            <el-cascader
                style="width: 50%"
                clearable
                placeholder="请选择部门"
                v-model="state.form.deptId"
                :options="state.options"
                @change="selectValue"
                :props="{ expandTrigger: 'hover', value: 'deptId',label: 'deptName',emitPath: false}">
            </el-cascader>

            <el-select
                clearable
                v-model="state.form.people"
                filterable
                multiple
                remote
                reserve-keyword
                placeholder="请输入签署人名称（可多选）"
                remote-show-suffix
                :remote-method="(val)=>getUserList(val,state.form.deptId)"
                style="width: 50%;margin-left: 10px"
            >
              <el-option
                  v-for="item in state.userList"
                  :key="item.userId"
                  :label="item.nickName"
                  :value="item.userId"
              />
            </el-select>
          </div>

        </el-form-item>
      </el-form>
      <template #footer>
        <span class="dialog-footer">
            <el-button @click="handleClose" size="default">取 消</el-button>
            <el-button type="primary"  @click="onSubmit" size="default" v-preReClick>创建项目</el-button>
        </span>
      </template>
    </el-dialog>
  </div>
</template>
<script setup>
import {reactive, ref, toRefs} from 'vue'
import {ElMessage} from "element-plus";
import {listDept} from "@/api/system/dept";
import {listUser} from "@/api/system/user";

const { proxy } = getCurrentInstance();
const dialogVisible = ref(false);
const title = ref("");
const busRef = ref();
const length = ref()
const emit = defineEmits(["getList"]);

const state = reactive({
  form: {
    id: '',
    deptId: '',
    people: []
  },
  options: [],
  userList: [],
  formRules:{
    deptId: [{ required: true, trigger: "blur", message:'请选择部门' }],
    people: [{ required: true, trigger: "blur", message:'请选择签署人' }],
  },
})


const openDialog = async (value) => {
  await getDept()
  dialogVisible.value = true;
}
const selectValue = (val) => {
  state.userList = []
  state.form.people = []
  getUserList("",val)

}

const getDept = () => {
  listDept().then(response => {
    state.options = proxy.handleTree(response.data, "deptId",'parentId','children');
    console.log('response',state.options)
  });
}


const onSubmit = async () => {
  const valid = await busRef.value.validate();
  if(valid){
    const {id, ...data} = JSON.parse(JSON.stringify(state.form))
    // const res = await addWarehouse(data)
    // if(res.code === 200){
    //   ElMessage({
    //     type: 'success',
    //     message: '新增成功'
    //   });
    // }else{
    //   ElMessage.warning(res.message)
    // }
    emit("getList")
    busRef.value.clearValidate();
    reset();
    dialogVisible.value = false;

  }
}

const handleClose = () => {
  busRef.value.clearValidate();
  reset();
  dialogVisible.value = false;
  emit("getList")
}
const reset = () => {
  state.form = {
    id: '',
    name: '',
    remark: '',
  }
}
const getUserList = async (val,deptId)=>{
  if(deptId == '' || deptId == null){
    ElMessage.warning("请选择部门！")
    return;
  }
  if(val != ""){
    const queryParams = {
      name: val,
    }
    const res = await listUser(queryParams)
    if (res.code == 200) {
      state.userList = res.rows
    } else {
      ElMessage.warning(res.message)
    }
  }else {
    const queryParams = {
      pageNum: 1,
      pageSize: 10,
      deptId: deptId
    }
    const res = await listUser(queryParams)
    if (res.code == 200) {
      state.userList = res.rows
    } else {
      ElMessage.warning(res.message)
    }
  }
}
defineExpose({
  openDialog
});

</script>

<style scoped lang="scss">
.notice{
  :deep(.el-form .el-form-item__label) {
    font-size: 15px;
  }
  .file {
    display: flex;
    flex-direction: column;
    align-items: flex-start;
  }
}
</style>
